DROP FUNCTION XML_TagID(VARCHAR);
DROP FUNCTION XML_AttID(VARCHAR);
DROP FUNCTION XML_NSID(VARCHAR);
DROP FUNCTION XML_PIID(VARCHAR);
DROP FUNCTION Get_TagID(VARCHAR);
DROP FUNCTION Get_AttID(VARCHAR);
DROP FUNCTION Get_NSID(VARCHAR);
DROP FUNCTION Get_PIID(VARCHAR);
DROP FUNCTION CreateElement(INTEGER,VARCHAR);
DROP FUNCTION CreateProcessingInstruction(INTEGER,VARCHAR,VARCHAR);
DROP FUNCTION CreateTextNode(INTEGER,VARCHAR);
DROP FUNCTION CreateComment(INTEGER,VARCHAR);
DROP FUNCTION addChildElement(INTEGER,VARCHAR);
DROP FUNCTION addChildPI(INTEGER,VARCHAR,VARCHAR);
DROP FUNCTION addChildText(INTEGER,VARCHAR);
DROP FUNCTION addChildComment(INTEGER,VARCHAR);
DROP FUNCTION SetAttribute(INTEGER,VARCHAR,VARCHAR);
DROP FUNCTION SetNamespace(INTEGER,VARCHAR,VARCHAR);
DROP FUNCTION appendChild(INTEGER,INTEGER);
DROP FUNCTION insertBefore(INTEGER,INTEGER);
DROP FUNCTION StringValue(INTEGER);

DROP LANGUAGE plpgsql CASCADE;